searchNodes=[{"doc":"Extrace provides functions for tracing events in a safe manner for single Erlang virtual machine, currently for function calls only. Functionality includes: Nicer to use interface (arguably) than :dbg or trace BIFs. Protection against dumb decisions (matching all calls on a node being traced, for example) Adding safe guards in terms of absolute trace count or rate-limiting Nicer formatting than default traces Tracing Elixir and Erlang Code The Erlang Trace BIFs allow to trace any Elixir and Erlang code at all. They work in two parts: pid specifications, and trace patterns. Pid specifications let you decide which processes to target. They can be specific pids, all pids, existing pids, or new pids (those not spawned at the time of the function call). The trace patterns represent functions. Functions can be specified in two parts: specifying the modules, functions, and arguments, and then with Erlang match specifications to add constraints to arguments (see calls/3 for details). What defines whether you get traced or not is the intersection of both: . _ , -- -- -- -- , _ _ , -- -- -- -- , _ , - &#39; `-,,-&#39; ` - , , - &#39; ,-&#39; &#39;-, `-, | Matching -&#39; &#39;- Matching | | Pids | Getting | Trace | | | Traced | Patterns | | -, ,- | &#39; - , &#39;-, ,-&#39; , - &#39; &#39; - , _ _ , - &#39;&#39; - , _ _ , - &#39; &#39; -- -- -- -- &#39; &#39; -- -- -- -- &#39; If either the pid specification excludes a process or a trace pattern excludes a given call, no trace will be received. Example Session First let's trace the :queue.new functions in any process: &gt; Extrace . calls ( { :queue , :new , :_ } , 1 ) 1 13 : 14 : 34.086078 &lt; 0.44 . 0 &gt; :queue . new Recon tracer rate limit tripped . The limit was set to 1 trace message at most, and Extrace let us know when that limit was reached. Let's instead look for all the :queue.in/2 calls, to see what it is we're inserting in queues: &gt; Extrace . calls ( { :queue , :in , 2 } , 1 ) 1 13 : 14 : 55.365157 &lt; 0.44 . 0 &gt; :queue . in ( a , { [ ] , [ ] } ) Recon tracer rate limit tripped . In order to see the content we want, we should change the trace patterns to use a fn that matches on all arguments in a list ( _ ) and returns :return . This last part will generate a second trace for each call that includes the return value: &gt; Extrace . calls ( { :queue , :in , fn ( _ ) -&gt; :return end } , 3 ) 1 13 : 15 : 27.655132 &lt; 0.44 . 0 &gt; :queue . in ( :a , { [ ] , [ ] } ) 13 : 15 : 27.655467 &lt; 0.44 . 0 &gt; :queue . in / 2 -- &gt; { [ :a ] , [ ] } 13 : 15 : 27.757921 &lt; 0.44 . 0 &gt; :queue . in ( :a , { [ ] , [ ] } ) Recon tracer rate limit tripped . Matching on argument lists can be done in a more complex manner: &gt; Extrace . calls ( ...&gt; { :queue , :_ , ...&gt; fn ( [ a , _ ] ) when is_list ( a ) ; is_integer ( a ) andalso a &gt; 1 -&gt; :return end } ...&gt; { 10 , 100 } ...&gt; ) 32 13 : 24 : 21.324309 &lt; 0.38 . 0 &gt; :queue . in ( 3 , { [ ] , [ ] } ) 13 : 24 : 21.371473 &lt; 0.38 . 0 &gt; :queue . in / 2 -- &gt; { [ 3 ] , [ ] } 13 : 25 : 14.694865 &lt; 0.53 . 0 &gt; :queue . split ( 4 , { [ 10 , 9 , 8 , 7 ] , [ 1 , 2 , 3 , 4 , 5 , 6 ] } ) 13 : 25 : 14.695194 &lt; 0.53 . 0 &gt; :queue . split / 2 -- &gt; { { [ 4 , 3 , 2 ] , [ 1 ] } , { [ 10 , 9 , 8 , 7 ] , [ 5 , 6 ] } } &gt; Extrace . clear :ok Note that in the pattern above, no specific function ( _ ) was matched against. Instead, the fn used restricted functions to those having two arguments, the first of which is either a list or an integer greater than 1 . The limit was also set using {10, 100} instead of an integer, making the rate-limiting at 10 messages per 100 milliseconds, instead of an absolute value. Any tracing can be manually interrupted by calling Extrace.clear/0 , or killing the shell process. Be aware that extremely broad patterns with lax rate-limiting (or very high absolute limits) may impact your node's stability in ways Extrace cannot easily help you with. In doubt, start with the most restrictive tracing possible, with low limits, and progressively increase your scope. See calls/3 for more details and tracing possibilities. Structure This library is production-safe due to taking the following structure for tracing: [ IO / Group leader ] &lt;- -- -- -- -- -- -- -- -- -- -- , | | [ shell ] -- -&gt; [ tracer process ] -- -- &gt; [ formatter ] The tracer process receives trace messages from the node, and enforces limits in absolute terms or trace rates, before forwarding the messages to the formatter. This is done so the tracer can do as little work as possible and never block while building up a large mailbox. The tracer process is linked to the shell, and the formatter to the tracer process. The formatter also traps exits to be able to handle all received trace messages until the tracer termination, but will then shut down as soon as possible. In case the operator is tracing from a remote shell which gets disconnected, the links between the shell and the tracer should make it so tracing is automatically turned off once you disconnect. If sending output to the Group Leader is not desired, you may specify a different pid() via the option :io_server in the calls/3 function. For instance to write the traces to a file you can do something like &gt; { :ok , dev } = File . open ( &quot;/tmp/trace&quot; , [ :write ] ) &gt; Extrace . calls ( { :queue , :in , fn ( _ ) -&gt; :return end } , 3 , &gt; [ { :io_server , dev } ] ) 1 &gt; Recon tracer rate limit tripped . &gt; File . close ( dev ) . The only output still sent to the Group Leader is the rate limit being tripped, and any errors. The rest will be sent to the other IO server (see http://erlang.org/doc/apps/stdlib/io_protocol.html ).","ref":"Extrace.html","title":"Extrace","type":"module"},{"doc":"Equivalent to calls/3 .","ref":"Extrace.html#calls/2","title":"Extrace.calls/2","type":"function"},{"doc":"Allows to set trace patterns and pid specifications to trace function calls. The basic calls take the trace patterns as tuples of the form {module, function, args} where: module is any Elixir or Erlang module (e.g Enum or :queue ) function is any atom representing a function, or the wildcard pattern ( :_ ) args is either the arity of a function ( 0 .. 255 ), a wildcard pattern ( :_ ), a match specification or a function from a shell session that can be transformed into a match specification There is also an argument specifying either a maximal count (a number) of trace messages to be received, or a maximal frequency ( {num, millisecs} ). Here are examples of things to trace: All calls from the :queue module, with 10 calls printed at most: Extrace.calls({:queue, :_, :_}, 10) All calls to :lists.seq(a, b) , with 100 calls printed at most: Extrace.calls({:lists, :seq, 2}, 100) All calls to :lists.seq(a, b) , with 100 calls per second at most: Extrace.calls({:lists, :seq, 2}, {100, 1000}) All calls to :lists.seq(a, b, 2) (all sequences increasing by two) with 100 calls at most: Extrace.calls({:lists, :seq, fn([_, _, 2]) -&gt; :ok end}, 100) All calls to :erlang.iolist_to_binary/1 made with a binary as an argument already (kind of useless conversion!): Extrace.calls({:erlang, :iolist_to_binary, fn([x]) when is_binary(x) -&gt; :ok end}, 10) Calls to the queue module only in a given process pid , at a rate of 50 per second at most: Extrace.calls({:queue, :_, :_}, {50, 1000}, [pid: pid]) Print the traces with the function arity instead of literal arguments: Extrace.calls(tspec, max, [args: :arity]) Matching the filter/2 functions of both dict and lists modules, across new processes only: Extrace.calls([{:dict, :filter, 2}, {:lists, :filter, 2}], 10, [pid: :new]) Tracing the handle_call/3 functions of a given module for all new processes, and those of an existing one registered with gproc : Extrace.calls({mod, :handle_call, 3}, {10, 100}, [{:pid, [{:via, :gproc, name}, :new]} Show the result of a given function call: Extrace.calls({mod, fun, fn(_) -&gt; :return end}, max, opts) or Extrace.calls({mod, fun, [{:_, [], [{:return_trace}]}]}, max, opts) , the important bit being the :return or the {:return_trace} match spec value. There's a few more combination possible, with multiple trace patterns per call, and more options: {:pid, pid_spec} : which processes to trace. Valid options is any of all , new , existing , or a process descriptor ( {a, b, c} , &quot;&lt;a.b.c&gt;&quot; , an atom representing a name, {:global, name} , {:via, registrar, name} , or a pid). It's also possible to specify more than one by putting them in a list. {:timestamp, :formatter | :trace} : by default, the formatter process adds timestamps to messages received. If accurate timestamps are required, it's possible to force the usage of timestamps within trace messages by adding the option {:timestamp, :trace} . {:args, :arity | :args} : whether to print arity in function calls or their (by default) literal representation. {:scope, :global | :local} : by default, only global (fully qualified function calls) are traced, not calls made internally. To force tracing of local calls, pass in {:scope, :local} . This is useful whenever you want to track the changes of code in a process that isn't called with module.fun(args) , but just fun(args) . {:formatter, fn(term) -&gt; io_data() end} : override the default formatting functionality provided by Extrace. {:io_server, pid() | atom()} : by default, recon logs to the current group leader, usually the shell. This option allows to redirect trace output to a different IO server (such as a file handle). Also note that putting extremely large max values (i.e. 99999999 or {10000, 1} ) will probably negate most of the safe-guarding this library does and be dangerous to your node. Similarly, tracing extremely large amounts of function calls (all of them, or all of :io for example) can be risky if more trace messages are generated than any process on the node could ever handle, despite the precautions taken by this library.","ref":"Extrace.html#calls/3","title":"Extrace.calls/3","type":"function"},{"doc":"Stops all tracing at once.","ref":"Extrace.html#clear/0","title":"Extrace.clear/0","type":"function"},{"doc":"The default trace formatting functionality provided by Extrace. This can be overridden by passing {:formatter, fn(term) -&gt; io_data() end} as an option to calls/3 .","ref":"Extrace.html#format/1","title":"Extrace.format/1","type":"function"},{"doc":"Returns tspec with its shellfun replaced with matchspec . This function is used by calls/2 and calls/3 .","ref":"Extrace.html#to_erl_tspec/1","title":"Extrace.to_erl_tspec/1","type":"function"},{"doc":"","ref":"Extrace.html#t:args/0","title":"Extrace.args/0","type":"type"},{"doc":"","ref":"Extrace.html#t:f/0","title":"Extrace.f/0","type":"type"},{"doc":"","ref":"Extrace.html#t:formatterfun/0","title":"Extrace.formatterfun/0","type":"type"},{"doc":"","ref":"Extrace.html#t:matchspec/0","title":"Extrace.matchspec/0","type":"type"},{"doc":"","ref":"Extrace.html#t:max/0","title":"Extrace.max/0","type":"type"},{"doc":"","ref":"Extrace.html#t:max_rate/0","title":"Extrace.max_rate/0","type":"type"},{"doc":"","ref":"Extrace.html#t:max_traces/0","title":"Extrace.max_traces/0","type":"type"},{"doc":"","ref":"Extrace.html#t:millisecs/0","title":"Extrace.millisecs/0","type":"type"},{"doc":"","ref":"Extrace.html#t:mod/0","title":"Extrace.mod/0","type":"type"},{"doc":"","ref":"Extrace.html#t:num_matches/0","title":"Extrace.num_matches/0","type":"type"},{"doc":"","ref":"Extrace.html#t:options/0","title":"Extrace.options/0","type":"type"},{"doc":"","ref":"Extrace.html#t:pidspec/0","title":"Extrace.pidspec/0","type":"type"},{"doc":"","ref":"Extrace.html#t:shellfun/0","title":"Extrace.shellfun/0","type":"type"},{"doc":"","ref":"Extrace.html#t:tspec/0","title":"Extrace.tspec/0","type":"type"},{"doc":"This module handles formatting Map &amp; Struct . more details can be found :recon_map .","ref":"Extrace.LimitFormatter.html","title":"Extrace.LimitFormatter","type":"module"},{"doc":"Formatting &amp; Trimming output to selected fields.","ref":"Extrace.LimitFormatter.html#limit_inspect/2","title":"Extrace.LimitFormatter.limit_inspect/2","type":"function"},{"doc":"Copyright (c) 2015 - 2016, Tatsuya Kawano All rights reserved. Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. Neither the name of recon_ex nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &quot;AS IS&quot; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.","ref":"original-license.html","title":"Original License","type":"extras"},{"doc":"Apache License Version 2.0, January 2004 http://www.apache.org/licenses/ TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION 1. Definitions. &quot;License&quot; shall mean the terms and conditions for use, reproduction, and distribution as defined by Sections 1 through 9 of this document. &quot;Licensor&quot; shall mean the copyright owner or entity authorized by the copyright owner that is granting the License. &quot;Legal Entity&quot; shall mean the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, &quot;control&quot; means (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (ii) ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial ownership of such entity. &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity exercising permissions granted by this License. &quot;Source&quot; form shall mean the preferred form for making modifications, including but not limited to software source code, documentation source, and configuration files. &quot;Object&quot; form shall mean any form resulting from mechanical transformation or translation of a Source form, including but not limited to compiled object code, generated documentation, and conversions to other media types. &quot;Work&quot; shall mean the work of authorship, whether in Source or Object form, made available under the License, as indicated by a copyright notice that is included in or attached to the work (an example is provided in the Appendix below). &quot;Derivative Works&quot; shall mean any work, whether in Source or Object form, that is based on (or derived from) the Work and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this License, Derivative Works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the Work and Derivative Works thereof. &quot;Contribution&quot; shall mean any work of authorship, including the original version of the Work and any modifications or additions to that Work or Derivative Works thereof, that is intentionally submitted to Licensor for inclusion in the Work by the copyright owner or by an individual or Legal Entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, &quot;submitted&quot; means any form of electronic, verbal, or written communication sent to the Licensor or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, the Licensor for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by the copyright owner as &quot;Not a Contribution.&quot; &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity on behalf of whom a Contribution has been received by Licensor and subsequently incorporated within the Work. 2. Grant of Copyright License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare Derivative Works of, publicly display, publicly perform, sublicense, and distribute the Work and such Derivative Works in Source or Object form. 3. Grant of Patent License. Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the Work to which such Contribution(s) was submitted. If You institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the Work or a Contribution incorporated within the Work constitutes direct or contributory patent infringement, then any patent licenses granted to You under this License for that Work shall terminate as of the date such litigation is filed. 4. Redistribution. You may reproduce and distribute copies of the Work or Derivative Works thereof in any medium, with or without modifications, and in Source or Object form, provided that You meet the following conditions: (a) You must give any other recipients of the Work or Derivative Works a copy of this License; and (b) You must cause any modified files to carry prominent notices stating that You changed the files; and (c) You must retain, in the Source form of any Derivative Works that You distribute, all copyright, patent, trademark, and attribution notices from the Source form of the Work, excluding those notices that do not pertain to any part of the Derivative Works; and (d) If the Work includes a &quot;NOTICE&quot; text file as part of its distribution, then any Derivative Works that You distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the Derivative Works, in at least one of the following places: within a NOTICE text file distributed as part of the Derivative Works; within the Source form or documentation, if provided along with the Derivative Works; or, within a display generated by the Derivative Works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify the License. You may add Your own attribution notices within Derivative Works that You distribute, alongside or as an addendum to the NOTICE text from the Work, provided that such additional attribution notices cannot be construed as modifying the License. You may add Your own copyright statement to Your modifications and may provide additional or different license terms and conditions for use, reproduction, or distribution of Your modifications, or for any such Derivative Works as a whole, provided Your use, reproduction, and distribution of the Work otherwise complies with the conditions stated in this License. 5. Submission of Contributions. Unless You explicitly state otherwise, any Contribution intentionally submitted for inclusion in the Work by You to the Licensor shall be under the terms and conditions of this License, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate license agreement you may have executed with Licensor regarding such Contributions. 6. Trademarks. This License does not grant permission to use the trade names, trademarks, service marks, or product names of the Licensor, except as required for reasonable and customary use in describing the origin of the Work and reproducing the content of the NOTICE file. 7. Disclaimer of Warranty. Unless required by applicable law or agreed to in writing, Licensor provides the Work (and each Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are solely responsible for determining the appropriateness of using or redistributing the Work and assume any risks associated with Your exercise of permissions under this License. 8. Limitation of Liability. In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any Contributor be liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this License or out of the use or inability to use the Work (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such Contributor has been advised of the possibility of such damages. 9. Accepting Warranty or Additional Liability. While redistributing the Work or Derivative Works thereof, You may choose to offer, and charge a fee for, acceptance of support, warranty, indemnity, or other liability obligations and/or rights consistent with this License. However, in accepting such obligations, You may act only on Your own behalf and on Your sole responsibility, not on behalf of any other Contributor, and only if You agree to indemnify, defend, and hold each Contributor harmless for any liability incurred by, or claims asserted against, such Contributor by reason of your accepting any such warranty or additional liability. END OF TERMS AND CONDITIONS","ref":"license.html","title":"License","type":"extras"},{"doc":"Extrace is an Elixir wrapper for Recon Trace .","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"The package can be installed by adding :extrace to your list of dependencies in mix.exs : def deps do [ { :extrace , &quot;~&gt; 0.3.0&quot; } ] end","ref":"readme.html#installation","title":"Overview - Installation","type":"extras"},{"doc":"Set point: iex&gt; Extrace . calls ( [ { Enum , :take_random , fn _ -&gt; :return end } , { Enum , :count , fn _ -&gt; :return end } ] , 100 , [ scope : :local ] ) 4 Note that the functions to be traced ( :take_random and :count in the example above) can only be private if scope: :local is set. One function executed: iex(2)&gt; Enum . take_random ( [ 1 , 2 , 3 , 4 ] , 200 ) [ 2 , 4 , 3 , 1 ] 18 : 42 : 10.834670 &lt; 0.183 . 0 &gt; Enum . take_random ( [ 1 , 2 , 3 , 4 ] , 200 ) 18 : 42 : 10.840212 &lt; 0.183 . 0 &gt; Enum . take_random ( %{ 0 =&gt; 2 , 1 =&gt; 4 , 2 =&gt; 3 , 3 =&gt; 1 } , 4 , [ ] ) 18 : 42 : 10.840949 &lt; 0.183 . 0 &gt; Enum . take_random ( %{ 0 =&gt; 2 , 1 =&gt; 4 , 2 =&gt; 3 , 3 =&gt; 1 } , 3 , [ 1 ] ) 18 : 42 : 10.841064 &lt; 0.183 . 0 &gt; Enum . take_random ( %{ 0 =&gt; 2 , 1 =&gt; 4 , 2 =&gt; 3 , 3 =&gt; 1 } , 2 , [ 3 , 1 ] ) 18 : 42 : 10.841202 &lt; 0.183 . 0 &gt; Enum . take_random ( %{ 0 =&gt; 2 , 1 =&gt; 4 , 2 =&gt; 3 , 3 =&gt; 1 } , 1 , [ 4 , 3 , 1 ] ) 18 : 42 : 10.841330 &lt; 0.183 . 0 &gt; Enum . take_random ( %{ 0 =&gt; 2 , 1 =&gt; 4 , 2 =&gt; 3 , 3 =&gt; 1 } , 0 , [ 2 , 4 , 3 , 1 ] ) 18 : 42 : 10.841440 &lt; 0.183 . 0 &gt; Enum . take_random / 3 -- &gt; [ 2 , 4 , 3 , 1 ] 18 : 42 : 10.841521 &lt; 0.183 . 0 &gt; Enum . take_random / 3 -- &gt; [ 2 , 4 , 3 , 1 ] 18 : 42 : 10.841606 &lt; 0.183 . 0 &gt; Enum . take_random / 3 -- &gt; [ 2 , 4 , 3 , 1 ] 18 : 42 : 10.841685 &lt; 0.183 . 0 &gt; Enum . take_random / 3 -- &gt; [ 2 , 4 , 3 , 1 ] 18 : 42 : 10.841959 &lt; 0.183 . 0 &gt; Enum . take_random / 3 -- &gt; [ 2 , 4 , 3 , 1 ] 18 : 42 : 10.842046 &lt; 0.183 . 0 &gt; Enum . take_random / 2 -- &gt; [ 2 , 4 , 3 , 1 ] Another function executed: iex(4)&gt; Enum . count ( [ 1 , 2 , 3 , 4 ] ) 4 18 : 42 : 27.383667 &lt; 0.183 . 0 &gt; Enum . count ( [ 1 , 2 , 3 , 4 ] ) 18 : 42 : 27.383795 &lt; 0.183 . 0 &gt; Enum . count / 1 -- &gt; 4","ref":"readme.html#examples","title":"Overview - Examples","type":"extras"},{"doc":"Copyright (c) 2015, 2016 Tatsuya Kawano under MIT License . Fork from https://github.com/tatsuya6502/recon_ex Copyright (c) 2019 redink Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"readme.html#copyright-and-license","title":"Overview - Copyright and License","type":"extras"}]